@@ -1213,7 +1213,7 @@ avi_file_open_wave (const gchar *file)
 /*  ja:AVIからAVIファイル構造体を求める
         file,ファイル名
        param,ストリーム番号
-        type,AVI_STREAM_AUDIO/AVI_STREAM_VIDEO
+        type,AVI_TYPE_AUDIO/AVI_TYPE_VIDEO
         rate,レート
        scale,スケール
     priority,優先度
@@ -1266,7 +1266,7 @@ avi_file_open (const gchar  *file,
             if (language)
               *language = 0;
             if (name)
-              *name = g_strdup ("Video #1");
+              *name = NULL;
           }
         break;
       case AVI_FILE_WAVE:/* ja:WAVEファイル */
@@ -1284,7 +1284,7 @@ avi_file_open (const gchar  *file,
             if (language)
               *language = 0;
             if (name)
-              *name = g_strdup ("Audio #1");
+              *name = NULL;
           }
     }
   if (avi_file)
@@ -1296,6 +1296,116 @@ avi_file_open (const gchar  *file,
 }
 
 
+/*  ja:メモリからAVIファイル構造体を求める
+    data,データ
+    type,AVI_TYPE_AUDIO/AVI_TYPE_VIDEO
+     RET,AVIファイル構造体,NULL:エラー                                      */
+AviFile *
+avi_file_open_memory (gconstpointer  data,
+                      gint          *type)
+{
+  AviFile *avi_file = NULL;
+
+  if (data)
+    {
+      gsize header, size;
+
+      if (bmih_get_size (data) == BMIH_SIZE && bmih_get_planes (data) == 1
+        && bmih_get_width (data) > 0 && bmih_get_height (data) > 0
+        && (bmih_get_bit_count (data) == 1 || bmih_get_bit_count (data) == 4
+        || bmih_get_bit_count (data) == 8 || bmih_get_bit_count (data) == 15
+        || bmih_get_bit_count (data) == 16 || bmih_get_bit_count (data) == 24
+        || bmih_get_bit_count (data) == 32)
+        && (bmih_get_compression (data) == BI_COMP_RGB
+                        || bmih_get_compression (data) == BI_COMP_RLE8
+                        || bmih_get_compression (data) == BI_COMP_RLE4
+                        || bmih_get_compression (data) == BI_COMP_BITFIELDS))
+        {
+          /* ja:AVIファイル構造体 */
+          avi_file = g_malloc0 (sizeof (AviFile));
+          avi_file->length = 1;     /* ja:有効な範囲 */
+          avi_file->entries = 1;    /* ja:インデックスの数 */
+          /* ja:ビデオ固有 */
+          avi_file->handler = AVI_STREAM_COMP_DIB;
+          if (bmih_get_compression (data) == BI_COMP_RGB
+                        || bmih_get_compression (data) == BI_COMP_BITFIELDS)
+            {
+              /* ja:無圧縮 */
+              header = bm_header_bytes (data);
+              size = bm_image_bytes (data);
+              avi_file->bmih = g_memdup (data, header);
+              avi_file->avi_memory
+                            = avi_memory_dup ((guint8 *)data + header, size);
+            }
+          else
+            {
+              BitmapInfoHeader *bmih;
+
+              /* ja:圧縮 */
+              bmih = g_malloc (bx_all_bytes
+                                (bmih_get_width (data), bmih_get_height (data),
+                                        bmih_get_bit_count (data), BI_COMP_RGB,
+                                                bmih_get_color_used (data)));
+              bitmap_expand (data, bmih);
+              /* ja:展開後のDIBをコピー */
+              header = bm_header_bytes (bmih);
+              size = bm_image_bytes (bmih);
+              avi_file->bmih = g_memdup (data, header);
+              avi_file->avi_memory
+                            = avi_memory_dup ((guint8 *)bmih + header, size);
+              g_free (bmih);
+            }
+          /* ja:インデックス */
+          avi_file->index = g_malloc (sizeof (AviIndex));
+          avi_file->index[0].offset = 0;
+          avi_file->index[0].size = size;
+          avi_file->index[0].key = TRUE;
+          if (type)
+            *type = AVI_TYPE_VIDEO;
+        }
+      else if (((guint8 *)data)[0] == 'R' && ((guint8 *)data)[1] == 'I'
+        && ((guint8 *)data)[2] == 'F' && ((guint8 *)data)[3] == 'F'
+        && ((guint8 *)data)[8] == 'W' && ((guint8 *)data)[9] == 'A'
+        && ((guint8 *)data)[10] == 'V' && ((guint8 *)data)[11] == 'E'
+        && ((guint8 *)data)[12] == 'f' && ((guint8 *)data)[13] == 'm'
+        && ((guint8 *)data)[14] == 't' && ((guint8 *)data)[15] == ' '
+        && (header = *(guint32 *)((guint8 *)data + 16))
+                                                >= WFX_SIZE - sizeof (guint16)
+        && header == wf_header_bytes ((guint8 *)data + 20)
+        && ((guint8 *)data)[(header + 1) / 2 * 2 + 20] == 'd'
+        && ((guint8 *)data)[(header + 1) / 2 * 2 + 21] == 'a'
+        && ((guint8 *)data)[(header + 1) / 2 * 2 + 22] == 't'
+        && ((guint8 *)data)[(header + 1) / 2 * 2 + 23] == 'a'
+        && (size = *(guint32 *)((guint8 *)data + (header + 1) / 2 * 2 + 24))
+            + header + sizeof (guint32) * 5 <= *(guint32 *)((guint8 *)data + 4)
+        && size / wfx_get_block_align ((guint8 *)data + 20) > 0)
+        {
+          /* ja:AVIファイル構造体 */
+          avi_file = g_malloc0 (sizeof (AviFile));
+          avi_file->avi_memory = avi_memory_dup ((guint8 *)data
+                                            + (header + 1) / 2 * 2 + 28, size);
+          avi_file->entries = 1;    /* ja:インデックスの数 */
+          /* ja:インデックス */
+          avi_file->index = g_malloc0 (sizeof (AviIndex));
+          avi_file->index[0].size = size;
+          /* ja:オーディオ固有 */
+          avi_file->wfx = g_malloc (MAX (header, WFX_SIZE));
+          wfx_set_size (avi_file->wfx, 0);
+          g_memmove (avi_file->wfx, (guint8 *)data + 20, header);
+          /* ja:AVIファイル構造体 */
+          avi_file->samples = size / wfx_get_block_align (avi_file->wfx);
+          avi_file->length = MAX ((glonglong)avi_file->samples
+                        * AVI_PCM_SAMPLES_PER_SEC
+                        * wfx_get_block_align (avi_file->wfx)
+                        / wfx_get_average_bytes_per_sec (avi_file->wfx), 1);
+          if (type)
+            *type = AVI_TYPE_AUDIO;
+        }
+    }
+  return avi_file;
+}
+
+
 /*  ja:AVIファイル構造体を解放する
     avi_file,AVIファイル構造体
          RET,TRUE:正常終了,FALSE:エラー                                     */
