@@ -203,7 +203,7 @@ avi_base_split_file (AviEdit    *avi_edit,
 /*  ja:AVIからAVIファイル構造体を求める
         file,ファイル名
        param,ストリーム番号
-        type,AVI_STREAM_AUDIO/AVI_STREAM_VIDEO
+        type,AVI_TYPE_AUDIO/AVI_TYPE_VIDEO
         rate,レート
        scale,スケール
     priority,優先度
@@ -221,6 +221,15 @@ avi_file_open (const gchar  *file,
                gchar       **name);
 
 
+/*  ja:メモリからAVIファイル構造体を求める
+    data,データ
+    type,AVI_TYPE_AUDIO/AVI_TYPE_VIDEO
+     RET,AVIファイル構造体,NULL:エラー                                      */
+AviFile *
+avi_file_open_memory (gconstpointer  data,
+                      gint          *type);
+
+
 /*  ja:AVIファイル構造体を解放する
     avi_file,AVIファイル構造体
          RET,TRUE:正常終了,FALSE:エラー                                     */
