@@ -371,6 +371,13 @@ AviEdit **
 avi_edit_open (const gchar *file);
 
 
+/*  ja:AVIをファイルから開く
+    data,データ
+     RET,AVI編集ハンドル,NULL:エラー                                        */
+AviEdit *
+avi_edit_open_from_memory (gconstpointer data);
+
+
 /*  ja:AVIを閉じる
     avi_edit,AVI編集ハンドル
          RET,TRUE:正常終了,FALSE:エラー                                     */
