@@ -218,9 +218,8 @@ avi_frame_get_bitmap (AviFrame   *avi_frame,
                       const gint  bit_count)
 {
   gint i, n;
-  AviCache avi_buf;
   AviEdit *avi_edit;
-  BitmapInfoHeader *bmih0, *bmih1;
+  BitmapInfoHeader *bmih0;
 
   if (!avi_frame)
     return NULL;
@@ -238,13 +237,15 @@ avi_frame_get_bitmap (AviFrame   *avi_frame,
                     && bmih_get_width (avi_edit->buf[i].data) == width
                     && bmih_get_height (avi_edit->buf[i].data) == height
                     && bmih_get_bit_count (avi_edit->buf[i].data) == bit_count)
-        {
-          /* ja:キャッシュに同じものがあるとき */
-          avi_buf = avi_edit->buf[i];
-          g_memmove (avi_edit->buf + 1, avi_edit->buf, i * sizeof (AviCache));
-          avi_edit->buf[0] = avi_buf;
-          return avi_buf.data;
-        }
+      {
+        /* ja:キャッシュに同じものがあるとき */
+        AviCache avi_buf;
+
+        avi_buf = avi_edit->buf[i];
+        g_memmove (avi_edit->buf + 1, avi_edit->buf, i * sizeof (AviCache));
+        avi_edit->buf[0] = avi_buf;
+        return avi_buf.data;
+      }
 
   /* ja:展開された元のフレームを取得 */
   bmih0 = avi_frame_get_bitmap_real (avi_frame, pos);
@@ -257,6 +258,8 @@ avi_frame_get_bitmap (AviFrame   *avi_frame,
       /* ja:色数を32ビットに変換する */
       if (bmih_get_bit_count (bmih0) != 32)
         {
+          BitmapInfoHeader *bmih1;
+
           bmih1 = g_malloc (bx_all_bytes (bmih_get_width (bmih0),
                                 bmih_get_height (bmih0), 32, BI_COMP_RGB, 0));
           bitmap_convert_32 (bmih0, bmih1);
@@ -266,6 +269,8 @@ avi_frame_get_bitmap (AviFrame   *avi_frame,
       /* ja:サイズを変換する */
       if (bmih_get_width (bmih0) != width || bmih_get_height (bmih0) != height)
         {
+          BitmapInfoHeader *bmih1;
+
           bmih1 = g_malloc (bx_all_bytes (width, height, 32, BI_COMP_RGB, 0));
           bmih_set_width (bmih1, width);
           bmih_set_height (bmih1, height);
@@ -276,6 +281,8 @@ avi_frame_get_bitmap (AviFrame   *avi_frame,
       /* ja:色数を変換する */
       if (bit_count != 32)
         {
+          BitmapInfoHeader *bmih1;
+
           bmih1 = g_malloc (bx_all_bytes
                                 (width, height, bit_count, BI_COMP_RGB, 0));
           bmih_set_color_used (bmih1, 0);
@@ -307,7 +314,7 @@ avi_frame_get_bitmap (AviFrame   *avi_frame,
           bmih0 = bmih1;
         }
     }
-  g_free (avi_edit->buf[AVI_EDIT_CACHE-1].data);
+  g_free (avi_edit->buf[AVI_EDIT_CACHE - 1].data);
   g_memmove (avi_edit->buf + 1, avi_edit->buf,
                                     (AVI_EDIT_CACHE - 1) * sizeof (AviCache));
   avi_edit->buf[0].data = bmih0;
@@ -329,10 +336,9 @@ avi_frame_get_raw (AviFrame  *avi_frame,
                    const gint  width,
                    const gint  height)
 {
-  gint i, n, xx, yy, src, dst;
+  gint i, n, xx, yy;
   guchar *p;
   guint8 *q;
-  AviCache avi_buf;
   AviEdit *avi_edit;
   BitmapInfoHeader *bmih;
 
@@ -353,6 +359,8 @@ avi_frame_get_raw (AviFrame  *avi_frame,
                                         && avi_edit->buf[i].height == height)
       {
         /* ja:キャッシュに同じものがあるとき */
+        AviCache avi_buf;
+
         avi_buf = avi_edit->buf[i];
         g_memmove (avi_edit->buf + 1, avi_edit->buf, i * sizeof (AviCache));
         avi_edit->buf[0] = avi_buf;
@@ -366,6 +374,8 @@ avi_frame_get_raw (AviFrame  *avi_frame,
   for (yy = 0; yy < height; yy++)
     for (xx = 0; xx < width; xx++)
       {
+        gint src, dst;
+
         src = xx * 4 + (height - yy - 1) * width * 4;
         dst = xx * 4 + yy * width * 4;
         p[dst]  = q[src + 2];
