@@ -65,8 +65,8 @@ avi_main_type (const gchar *file)
                                     && buffer[10 ]== 'V' && buffer[11] == 'E')
     return AVI_FILE_WAVE;/* ja:WAVEファイル */
   else if (buffer[0] == '#' && buffer[1] == 'V' && buffer[2] == 'M'
-                                    && buffer[3] == 'A' && buffer[4] == 'I'
-                                    && buffer[5] == 'D' && buffer[6] == '\n')
+                    && buffer[3] == 'A' && buffer[4] == 'I' && buffer[5] == 'D'
+                                && (buffer[6] == '\n' || buffer[6] == '\r'))
     return AVI_FILE_SCENARIO;/* ja:シナリオオブジェクト */
   return AVI_FILE_UNKNOWN;
 }
@@ -301,16 +301,90 @@ avi_edit_open (const gchar *file)
       streams = avi_main_streams (file);
       if (streams > 0)
         {
-          gint i;
+          gint i, j = 0;
 
           avi_edit = g_malloc ((streams + 1) * sizeof (AviEdit *));
           for (i = 0; i < streams; i++)
             {
-              avi_edit[i] = avi_edit_open_with_param (file, i);
-              if (!avi_edit[i])
-                break;
+              avi_edit[j] = avi_edit_open_with_param (file, i);
+              if (avi_edit[j])
+                j++;
             }
-          avi_edit[i] = NULL;
+          avi_edit[j] = NULL;
+          avi_edit = g_realloc (avi_edit,
+                                    (j > 0 ? j + 1 : 0) * sizeof (AviEdit *));
+        }
+    }
+  return avi_edit;
+}
+
+
+/*  ja:AVIをファイルから開く
+    data,データ
+     RET,AVI編集ハンドル,NULL:エラー                                        */
+AviEdit *
+avi_edit_open_from_memory (gconstpointer data)
+{
+  gint type;
+  AviEdit *avi_edit = NULL;
+  AviFile *avi_file;
+
+  avi_file = avi_file_open_memory (data, &type);
+  if (avi_file)
+    {
+      /* ja:AVI編集ハンドル */
+      avi_edit = g_malloc0 (sizeof (AviEdit));
+      avi_edit->file = avi_file;
+      avi_edit->type = type;
+      avi_edit->length = avi_file->length;
+      if (type == AVI_TYPE_VIDEO)
+        {
+          /* ja:ビデオ */
+          avi_edit->rate = 1;
+          avi_edit->scale = 1;
+          avi_edit->bmih = g_memdup (avi_file->bmih,
+                                            bm_header_bytes (avi_file->bmih));
+          if (bmih_get_size_image (avi_edit->bmih) <= 0)
+            bmih_set_size_image (avi_edit->bmih,
+                                            bm_image_bytes (avi_edit->bmih));
+        }
+      else if (type == AVI_TYPE_AUDIO)
+        {
+          /* ja:オーディオ */
+          if (wfx_get_format_tag (avi_file->wfx) == WAVE_FMT_PCM)
+            {
+              avi_edit->wfx = g_memdup (avi_file->wfx,
+                                            wf_header_bytes (avi_file->wfx));
+            }
+          else
+            {
+              AcmObject *acm_object;
+
+              /* ja:圧縮 */
+              acm_object = acm_open (wfx_get_format_tag (avi_edit->file->wfx));
+              if (!acm_object
+                    || !(avi_edit->wfx = g_malloc
+                                (acm_decompress_get_format_size (acm_object,
+                                                        avi_edit->file->wfx)))
+                    || (!acm_decompress_get_format (acm_object,
+                                            avi_edit->file->wfx, avi_edit->wfx)
+                                                    | !acm_close (acm_object)))
+                {
+                  avi_file_close (avi_edit->file);
+                  g_free (avi_edit->wfx);
+                  g_free (avi_edit);
+                  return NULL;
+                }
+            }
+          avi_edit->rate = wfx_get_average_bytes_per_sec (avi_edit->wfx);
+          avi_edit->scale = wfx_get_block_align (avi_edit->wfx);
+        }
+      else
+        {
+          /* ja:エラー */
+          avi_file_close (avi_file);
+          g_free (avi_edit);
+          return NULL;
         }
     }
   return avi_edit;
